pub struct SourceJournalistKeyRequest {}Expand description
Source fetches journalist keys for the newsroom
This is part of step 5 in the spec.
Note: This isn’t currently written down in the spec, but should occur right before the server provides a long-term key and an ephmeral key bundle for the journalist.